kedro.framework.project.validate_settings — Kedro 0.17.6 documentation

# kedro.framework.project.validate_settings

`kedro.framework.project.` `validate_settings`()

  Eagerly validate that the settings module is importable. This is desirable to surface any syntax or import errors early. In particular, without eagerly importing the settings module, dynaconf would silence any import error (e.g. missing dependency, missing/mislabelled pipeline), and users would instead get a cryptic error message `Expected an instance of `ConfigLoader`, got `NoneType` instead`. More info on the dynaconf issue: https://github.com/rochacbruno/dynaconf/issues/460